Skip to contents

Sort variance partitioning fractions

Usage

sortCols(
  x,
  FUN = mean,
  decreasing = TRUE,
  last = c("CountNoise", "Residuals"),
  ...
)

# S4 method for class 'data.frame'
sortCols(
  x,
  FUN = mean,
  decreasing = TRUE,
  last = c("CountNoise", "Residuals"),
  ...
)

Arguments

x

object returned by fitVarPart()

FUN

function giving summary statistic to sort by. Defaults to mean()

decreasing

logical. Should the sorting be increasing or decreasing?

last

columns to be placed on the right, regardless of values in these columns

...

other arguments

Value

tibble with columns sorted by mean value, with Residuals in last column